#include "icm40608.h"
#include <math.h>
#include "Icm406xxDriver_HL.h"
#include "Icm406xxExtFunc.h"
#include "ErrorHelper.h"
#include "Icm406xxDriver_HL_apex.h"
//4:1  spi_mode
// 0   soft_reset_config value: 1 enable reset; 0 Normal
#define DEVICE_CONFIG_1 (0x11)

//5:3  I2C_SLEW_RATE
//2:0	SPI_SLEW_RATE
#define DEVICE_CONFIG_2 (0x13)

//5 INT2_MODE
//4 INT2_DRIVE_CIRCUIT
//3 INT2_POLARITY
//2 INT1_MODE
//1 INT1_DRIVE_CIRCUIT
//0 INT1_POLARITY
#define INT_CONFIG (0x14)

//7:6 FIFO_MODE
//00: Bypass Mode (default)
//01: Stream-to-FIFO Mode
//10: STOP-on-FULL Mode
//11: STOP-on-FULL Mode
#define FIFO_CONFIG (0x16)

//7:0 temp_data[15:8]
#define TEMP_DATA1 (0x1D)

//7:0 temp_data[7:0]
#define TEMP_DATA0 (0x1E)

//7:0 accel_data_x[15:8]
#define ACCEL_DATA_X1 (0x1F)

//7:0 accel_data_x[7:0]
#define ACCEL_DATA_X0 (0x20)

//7:0 accel_data_y[15:8]
#define ACCEL_DATA_Y1 (0x21)

//7:0 accel_data_y[7:0]
#define ACCEL_DATA_Y0 (0x22)

//7:0 accel_data_z[15:8]
#define ACCEL_DATA_Z1 (0x23)

//7:0 accel_data_z[7:0]
#define ACCEL_DATA_Z0 (0x24)

//7:0 gryo_data_x[15:8]
#define GRYO_DATA_X1 (0x25)

//7:0 gryo_data_x[7:0]
#define GRYO_DATA_X0 (0x26)

//7:0 gryo_data_y[15:8]
#define GRYO_DATA_Y1 (0x27)

//7:0 gyro_data_y[7:0]
#define GRYO_DATA_Y0 (0x28)

//7:0 gryo_data_z[15:8]
#define GRYO_DATA_Z1 (0x29)

//7:0 gryo_data_z[7:0]
#define GRYO_DATA_Z0 (0x2A)

//?????????????????????????????
//TMST_FSYNC_DATA[15:8]
#define TMST_FSYNCH (0x2B)

//TMST_FSYNC_DATA[7:0]
#define TMST_FSYNCL (0x2C)
//????????????????????????????????

//6 UI_FSYNC_INT
//5 PLL_RDY_INT
//3 DATA_RDY_INT
//2 FIFO_THS_INT
//1	FIFO_FULL_INT
//0 AGC_RDY_INT
#define INT_STATUS (0x2D)

//fifo_count[15:8]
#define FIFO_COUNTH (0x2E)

//fifo_count[7:0]
#define FIFO_COUNTL (0x2F)

//？？
#define FIFO_DATA (0x30)

//7:0 STEP_CNT[7:0]
#define APEX_DATA0 (0x31)

//7:0 STEP_CNT[15:8]
#define APEX_DATA1 (0x32)

//7:0 STEP_CADENCE ??????
#define APEX_DATA2 (0x33)

//1:0 01 walk
//    10 run
#define APEX_DATA3 (0x34)

//0 	TAP_DIR
//2:1 	TAP_AXIS
//4:3	TAP_NUM
#define APEX_DATA4 (0x35)

//3	SMD_INT
//2	WOM_Z_INT
//1	WOM_Y_INT
//0	WOM_X_INT
#define INT_STATUS2 (0x37)

//5	STEP_DET_INT
//4	STEP_CNT_OVF_INT
//3	TILT_DET_INT
//2	WAKE_INT
//1	SLEEP_INT
//0	TAP_DET_INT
#define INT_STATUS3 (0x38)

//6 DMP_INIT_EN
//5 DMP_MEM_RESET_EN
//2 TMST_STROBE
//1 FIFO_FLUSH
#define SIGNAL_PATH_RESET (0x4B)

//7	FIFO_HOLD_LAST_DATA_EN
//6	FIFO_COUNT_REC
//5	FIFO_COUNT_ENDIAN
//4	SENSOR_DATA_ENDIAN
//1:0 UI_SIFS_CFG  10 Disable SPI
//				   11 Disable I2c
#define INTF_CONFIG0 (0x4C)

//3	ACCEL_LP_CLK_SEL
//1:0 	00: Always select internal RC oscillator
//		01: Select PLL when available, else select RC oscillator (default)
//		10: Reserved
//		11: Disable all clocks
#define INTF_CONFIG1 (0x4D)

//4:	IDLE
//3:2 	GYRO_MODE
//1:0	ACCEL_MODE
#define PWR_MGMT0 (0x4E)

//7:5	GYRO_FS_SEL
//3:0	GYRO_ODR
#define GYRO_CONFIG0 (0x4F)

//7:5	ACCEL_FS_SEL
//3:0	ACCEL_ODR
#define ACCEL_CONFIG0 (0x50)

//7:5	TEMP_FILT_BW
//3:2	GYRO_UI_FILT_ORD
//1:0	GYRO_DEC2_M2_ORD
#define GYRO_CONFIG1 (0x51)

//7:4	ACCEL_UI_FILT_BW
//3:0	GYRO_UI_FILT_BW
#define GYRO_ACCEL_CONFIG0 (0x52)

//4:3 ACCEL_UI_FILT_ORD
//2:1 ACCEL_DEC2_MS_ORD
#define ACCEL_CONFIG1 (0x53)

//3: TMST_RES
//2: TMST_DELTA_En
//1：TMST_FSYNC_EN
//0: TMST_EN
#define TMST_CONFIG (0x54)

//7：DMP_POWER_AVE
//6: TAP_ENABLE
//5: PED_ENABLE
//4：TILT_ENABLE
//3: R2W_EN
//1:0 DMP_ODR
#define APEX_CONFIG0 (0x56)

//3：WOM_INT_MODE
//2: WOM_MODE
//1: SMD_MODE
#define SMD_CONFIG (0x57)

//6: FIFO_RESUME_PARTIAL_RD
//5: FIFO_WM_GT_TH
//3：FIFO_TMST_FSYNC_EN
//2: FIFO_TEMP_EN
//1: FIFO_GYRO_EN
//0: FIFO_ACCEL_EN
#define FIFO_CONFIG1 (0x5F)

//7:0 FIFO_WM[7:0]
#define FIFO_CONFIG2 (0x60)

//3:0 FIFO_WM[11:8]
#define FIFO_CONFIG3 (0x61)

//6:4 FSYNC_UI_SEL
//1	FSYNC_UI_FLAG_LEAR_SEL
//0 FSYNC_POLARITY
#define FSNC_CONFIG (0x62)

//5:4	UI_DRDY_INT_CLEAR
//3:2	FIFO_THS_INT_CLEAR
//1:0	FIFO_FULL_INT_CLEAR
#define INT_CONFIG0 (0x63)

//6 UI_FSYNC_INT1_EN
//5 PLL_RDY_INT1_EN
//3 UI_DRDY_INT1_EN
//2 FIFO_THS_INT1_EN
//1	FIFO_FULL_INT1_EN
//0 UI_AGC_TDY_INT1_EN
#define INT_SOURCE0 (0x65)

//3: SMD_INT1_EN
//2: WOM_Z_INT1_EN
//1: WOM_Y_INT1_EN
//0: WOM_X_INT1_EN
#define INT_SOURCE1 (0x66)

//#define	INT_SOURCE2			(0x66)
#define INT_SOURCE3 (0x68)
#define INT_SOURCE4 (0x69)
#define FIFO_LOST_PKT0 (0x6C)

#define FIFO_LOST_PKT1 (0x6D)

#define SELF_TEST_CONFIG (0x70)

//The default value is 0x39
#define WHO_AM_I (0x75)

#define REG_BANK_SEL (0x76)

//
#define SENSOR_CONFIG0 (0x03)

#define GYRO_CONFIG_STATIC2 (0x0B)

#define GYRO_CONFIG_STATIC3 (0x0C)

#define GYRO_CONFIG_STATIC3 (0x0C)
#define GYRO_CONFIG_STATIC4 (0x0D)
#define GYRO_CONFIG_STATIC5 (0x0E)
#define GYRO_CONFIG_STATIC6 (0x0F)
#define GYRO_CONFIG_STATIC7 (0x10)
#define GYRO_CONFIG_STATIC8 (0x11)
#define GYRO_CONFIG_STATIC9 (0x12)
#define GYRO_CONFIG_STATIC10 (0x13)

#define XG_ST_DATA (0x5F)
#define YG_ST_DATA (0x60)
#define ZG_ST_DATA (0x61)
#define TMSTVAL0 (0x62)
#define TMSTVAL1 (0x63)
#define TMSTVAL2 (0x64)

#define REG_BANK_SEL (0x76)
#define INTF_CONFIG4 (0x7A)
#define INTF_CONFIG5 (0x7B)

#define ACCEL_CONFIG_STATIC2 (0x03)
#define ACCEL_CONFIG_STATIC3 (0x04)
#define ACCEL_CONFIG_STATIC4 (0x05)

#define XA_ST_DATA (0x3B)
#define YA_ST_DATA (0x3C)
#define ZA_ST_DATA (0x3D)

#define REG_BANK_SEL (0x76)

#define APEX_CONFIG1 (0x40)
#define APEX_CONFIG2 (0x41)
#define APEX_CONFIG3 (0x42)
#define APEX_CONFIG4 (0x43)
#define APEX_CONFIG5 (0x44)
#define APEX_CONFIG6 (0x45)
#define APEX_CONFIG7 (0x46)
#define APEX_CONFIG8 (0x47)
#define APEX_CONFIG9 (0x48)

#define MPUREG_SIGNAL_PATH_RESET 0x4B
#define MPUREG_INTF_CONFIG0 0x4C
#define MPUREG_INTF_CONFIG1 0x4D

#define INT_SOURCE7 (0x4E)

#define INT_SOURCE8 (0x4F)

#define REG_BANK_SEL (0x76)

#define OFFSET_USER0 (0x77)
#define OFFSET_USER1 (0x78)
#define OFFSET_USER2 (0x79)
#define OFFSET_USER3 (0x7A)
#define OFFSET_USER4 (0x7B)
#define OFFSET_USER5 (0x7C)
#define OFFSET_USER6 (0x7D)
#define OFFSET_USER7 (0x7E)
#define OFFSET_USER8 (0x7F)

/* ACCEL_FS_SEL */
#define BIT_ACCEL_CONFIG0_FS_SEL_POS 5
#define BIT_ACCEL_CONFIG0_FS_SEL_MASK (0x7 << BIT_ACCEL_CONFIG0_FS_SEL_POS)

/* ACCEL_ODR */
#define BIT_ACCEL_CONFIG0_ODR_POS 0
#define BIT_ACCEL_CONFIG0_ODR_MASK 0x0F

/* GYRO_FS_SEL*/
#define BIT_GYRO_CONFIG0_FS_SEL_POS 5
#define BIT_GYRO_CONFIG0_FS_SEL_MASK (7 << BIT_GYRO_CONFIG0_FS_SEL_POS)

/* GYRO_ODR */
#define BIT_GYRO_CONFIG0_ODR_POS 0
#define BIT_GYRO_CONFIG0_ODR_MASK 0x0F

#define ACC_GYRO_LN 0x0f
#define ACC_LP_GYRO_STANDY 0x06
#define ACC_LP_GYRO_LN 0x0E
#define ACC_OFF_GYRO_OFF 0x00

#define ICM_WRITE_ADDRESS 0x68
#define ICM_READ_ADDRESS 0x68
#define DEVICE_ID 0x39

#define ICM_PEDOMETER_FREQUENCY_MODE ICM406XX_APEX_CONFIG0_DMP_ODR_25Hz
#define ICM_PEDOMETER_POWER_SAVE_MODE ICM406XX_APEX_CONFIG0_DMP_POWER_SAVE_EN
#define ICM_PEDOMETER_VALID_STEP_THRESHOLD ICM406XX_APEX_CONFIG2_PEDO_AMP_TH_2885681_MG
#define ICM_PEDOMETER_STEP_COUNTER_THRESHOLD 10
#define ICM_PEDOMETER_NON_WALK_DURATION ICM406XX_APEX_CONFIG3_PEDO_SB_TIMER_TH_100_SAMPLES
#define ICM_PEDOMETER_STEP_DETECTOR_THRESHOLD 1
#define ICM_PEDOMETER_SENSITIVITY_MODE ICM406XX_APEX_CONFIG9_SENSITIVITY_MODE_NORMAL

typedef union {
    uint8_t data_uint[2];
    int16_t data;
} data_union;


struct inv_icm406xx_serif icm406xx_serif;

/* Icm406xx driver object */
struct inv_icm406xx icm_driver;
typedef struct
{
    iic_write   write_fun;
    iic_read    read_fun;
	systick_get inv_systick_get;
	sys_sleep_us inv_systick_sleep;
	int_get_rawdata get_rawdata;
	icm40608_close_cb close_cb;
}InvIicOpera;
static InvIicOpera inviicopera = {0};

///* DMP ODR */
//static uint8_t dmp_odr_hz;

void icm40608_register_write(uint8_t register_address, uint8_t value)
{
    uint8_t w2_data[2];

    w2_data[0] = register_address;
    w2_data[1] = value;

    inviicopera.write_fun(ICM_WRITE_ADDRESS, w2_data, sizeof(w2_data), false);
}

void icm40608_register_write_Array(uint8_t register_address, uint8_t *pvalue, uint8_t length)
{
    uint8_t w2_data[256];

    w2_data[0] = register_address;
    memcpy(&w2_data[1], pvalue, length);
    //w2_data[1] = value;

    inviicopera.write_fun(ICM_WRITE_ADDRESS, w2_data, length + 1, false);
}

void icm40608_register_read(uint8_t register_address, uint8_t *destination, uint8_t number_of_bytes)
{
    inviicopera.write_fun(ICM_WRITE_ADDRESS, &register_address, 1, false);

    inviicopera.read_fun(ICM_WRITE_ADDRESS, destination, number_of_bytes);
}

static uint8_t Icm40608_read_ID(void)
{
    uint8_t id = 0x00;
    icm40608_register_read(WHO_AM_I, &id, 1);
    return id;
}



int8_t Icm40608_set_sample_rate(uint8_t accel_rate, uint8_t gyro_rate)
{
    typedef struct
    {
        uint8_t rate_num;
        uint8_t rate_def;
    } _sample_rate;
    _sample_rate accel_sample_rate_index[] =
        {
            {1, ICM406XX_ACCEL_CONFIG0_ODR_1_5625_HZ}, /*!< 1.5625 Hz (640 ms)*/
            {3, ICM406XX_ACCEL_CONFIG0_ODR_3_125_HZ},  /*!< 3.125 Hz (320 ms)*/
            {6, ICM406XX_ACCEL_CONFIG0_ODR_6_25_HZ},   /*!< 6.25 Hz (160 ms)*/
            {12, ICM406XX_ACCEL_CONFIG0_ODR_12_5_HZ},  /*!< 12.5 Hz (80 ms)*/
            {25, ICM406XX_ACCEL_CONFIG0_ODR_25_HZ},    /*!< 25 Hz (40 ms)*/
            {50, ICM406XX_ACCEL_CONFIG0_ODR_50_HZ},    /*!< 50 Hz (20 ms)*/
            {100, ICM406XX_ACCEL_CONFIG0_ODR_100_HZ},  /*!< 100 Hz (10 ms)*/
            {200, ICM406XX_ACCEL_CONFIG0_ODR_200_HZ}   /*!< 100 Hz (10 ms)*/
        };
    _sample_rate gyro_sample_rate_index[] =
        {
            {12, ICM406XX_GYRO_CONFIG0_ODR_12_5_HZ}, /*!< 12.5 Hz (80 ms)*/
            {25, ICM406XX_GYRO_CONFIG0_ODR_25_HZ},   /*!< 25 Hz (40 ms)*/
            {50, ICM406XX_GYRO_CONFIG0_ODR_50_HZ},   /*!< 50 Hz (20 ms)*/
            {100, ICM406XX_GYRO_CONFIG0_ODR_100_HZ}, /*!< 100 Hz (10 ms)*/
            {200, ICM406XX_GYRO_CONFIG0_ODR_200_HZ}  /*!< 200 Hz (5 ms)*/
        };

    for (uint8_t i = 0; i < (sizeof(accel_sample_rate_index) / sizeof(_sample_rate)); i++)
    {
        if (accel_rate <= accel_sample_rate_index[i].rate_num)
        {
            accel_rate = accel_sample_rate_index[i].rate_def;
            break;
        }
    }

    for (uint8_t i = 0; i < (sizeof(gyro_sample_rate_index) / sizeof(_sample_rate)); i++)
    {
        if (gyro_rate <= gyro_sample_rate_index[i].rate_num)
        {
            gyro_rate = gyro_sample_rate_index[i].rate_def;
            break;
        }
    }

    //uint8_t accconfig = ICM406XX_ACCEL_CONFIG0_FS_SEL_4g | accel_rate;
    //uint8_t gryoconfig = ICM406XX_GYRO_CONFIG0_FS_SEL_250dps | gyro_rate;
	uint8_t data = 0;
	icm40608_register_read(ACCEL_CONFIG0,&data,1);
	
	uint8_t accconfig = (data & (~(0x0F << 0))) | accel_rate;
	icm40608_register_write(ACCEL_CONFIG0, accconfig);

	icm40608_register_read(GYRO_CONFIG0,&data,1);
	
	uint8_t gryoconfig = (data & (~(0x0F << 0))) | gyro_rate;

    icm40608_register_write(GYRO_CONFIG0, gryoconfig);
    // //acc LN mode
    //gyro LN mode
    icm40608_register_write(PWR_MGMT0, ACC_LP_GYRO_LN);

    return 0;
}

void Icm40608_Gyro_Poweroff(void)
{
	// uint8_t data = 0x00;
    // icm40608_register_read(PWR_MGMT0, &data, 1);
	// if(!(data & 0x02))
	// {
		icm40608_register_write(PWR_MGMT0, 0x02);
	// }
}

void Icm40608_Mode_Set(ICM40608_WORKMODE_SET_E workmode)
{
    uint8_t data = 0x00;
    icm40608_register_read(PWR_MGMT0, &data, 1);
    switch (workmode)
    {
    case ICM40608_GYRO_OFF:
        data &= ~(0x03 << 2);
        data |= (0x00 << 2);
        break;
    case ICM40608_GYRO_STANDBY:
        data &= ~(0x03 << 2);
        data |= (0x01 << 2);
        break;
    case ICM40608_GYRO_LN:
        data &= ~(0x03 << 2);
        data |= (0x03 << 2);
        break;
    case ICM40608_ACCEL_OFF:
        data &= ~(0x03 << 0);
        data |= (0x00 << 0);
        break;
    case ICM40608_ACCEL_LN:
        data &= ~(0x03 << 0);
        data |= (0x03 << 0);
        break;
    case ICM40608_ACCEL_LP:
        data &= ~(0x03 << 0);
        data |= (0x02 << 0);
        break;
    default:
        break;
    }
    icm40608_register_write(PWR_MGMT0, data);
    inviicopera.inv_systick_sleep(200);
}

uint8_t Icm40608_Acc_Range_Get(void)
{
    uint8_t data = 0x00;
    icm40608_register_read(ACCEL_CONFIG0, &data, 1);
    //return (ACC_RANGE_E)(data & (0x07 << 5));
    uint32_t range = (data & (0x07 << 5));
    uint8_t temp = 0;
    switch (range)
    {
    case ICM40608_ACC_RANGE_2G:
        temp = 2;
        break;
    case ICM40608_ACC_RANGE_4G:
        temp = 4;
        break;
    case ICM40608_ACC_RANGE_8G:
        temp = 8;
        break;
    case ICM40608_ACC_RANGE_16G:
        temp = 16;
        break;
    default:
        break;
    }
    return temp;
}
void Icm40608_Acc_Range_Set(ACC_RANGE_E range)
{
    uint8_t data = 0x00;
    icm40608_register_read(ACCEL_CONFIG0, &data, 1);
    switch (range)
    {
    case ICM40608_ACC_RANGE_2G:
        data &= ~(0x07 << 5);
        data |= (0x03 << 5);
        break;
    case ICM40608_ACC_RANGE_4G:
        data &= ~(0x07 << 5);
        data |= (0x02 << 5);
        break;
    case ICM40608_ACC_RANGE_8G:
        data &= ~(0x07 << 5);
        data |= (0x01 << 5);
        break;
    case ICM40608_ACC_RANGE_16G:
        data &= ~(0x07 << 5);
        data |= (0x00 << 5);
        break;
    default:
        break;
    }
    icm40608_register_write(ACCEL_CONFIG0, data);
}

uint16_t Icm40608_Gyro_Range_Get(void)
{
    uint8_t data = 0x00;
    icm40608_register_read(GYRO_CONFIG0, &data, 1);
    uint32_t range = (data & (0x07 << 5));
    uint16_t temp = 0;
    switch (range)
    {
    case ICM40608_GYRO_RANGE_2000:
        temp = 2000; //2000
        break;
    case ICM40608_GYRO_RANGE_1000:
        temp = 1000; //1000
        break;
    case ICM40608_GYRO_RANGE_500:
        temp = 500; //500
        break;
    case ICM40608_GYRO_RANGE_250:
        temp = 250; //250
        break;
    case ICM40608_GYRO_RANGE_125:
        temp = 125; //125
        break;
    default:
        temp = 0x00; //2000
        break;
    }
    return temp;
}

void Icm40608_Gyro_Range_Set(GYRO_RANGE_E range)
{
    uint8_t data = 0x00;
    icm40608_register_read(GYRO_CONFIG0, &data, 1);
    switch (range)
    {
    case ICM40608_GYRO_RANGE_2000:
        data &= ~(0x07 << 5);
        data |= (0x00 << 5);
        break;
    case ICM40608_GYRO_RANGE_1000:
        data &= ~(0x07 << 5);
        data |= (0x01 << 5);
        break;
    case ICM40608_GYRO_RANGE_500:
        data &= ~(0x07 << 5);
        data |= (0x02 << 5);
        break;
    case ICM40608_GYRO_RANGE_250:
        data &= ~(0x07 << 5);
        data |= (0x03 << 5);
        break;
    case ICM40608_GYRO_RANGE_125:
        data &= ~(0x07 << 5);
        data |= (0x04 << 5);
        break;
    default:
        break;
    }
    icm40608_register_write(GYRO_CONFIG0, data);
}

void Icm40608_ReadAcc(PAccData_St paccdata)
{

    uint8_t buf[6];

    icm40608_register_read(ACCEL_DATA_X1, buf, 6);

    paccdata->acc_x = (short)(((uint16_t)buf[0] << 8) | buf[1]);
    if (paccdata->acc_x & 0x8000)
    {
        paccdata->acc_x -= 65536;
    }

    paccdata->acc_y = (short)(((uint16_t)buf[2] << 8) | buf[3]);
    if (paccdata->acc_y & 0x8000)
    {
        paccdata->acc_y -= 65536;
    }

    paccdata->acc_z = (short)(((uint16_t)buf[4] << 8) | buf[5]);
    if (paccdata->acc_z & 0x8000)
    {
        paccdata->acc_z -= 65536;
    }
}

void Icm40608_ReadGyro(PGyroData_St pgyrodata)
{
    uint8_t buf[6];

    icm40608_register_read(GRYO_DATA_X1, buf, 6);

    pgyrodata->gyro_x = (short)(((uint16_t)buf[0] << 8) | buf[1]);
    if (pgyrodata->gyro_x & 0x8000)
    {
        pgyrodata->gyro_x -= 65536;
    }

    pgyrodata->gyro_y = (short)(((uint16_t)buf[2] << 8) | buf[3]);
    if (pgyrodata->gyro_y & 0x8000)
    {
        pgyrodata->gyro_y -= 65536;
    }

    pgyrodata->gyro_z = (short)(((uint16_t)buf[4] << 8) | buf[5]);
    if (pgyrodata->gyro_z & 0x8000)
    {
        pgyrodata->gyro_z -= 65536;
    }
}

void Icm40608_Read_AllData(PIcm40608Data_St picm40608data)
{
    Icm40608_ReadAcc(&picm40608data->acc_data);

    Icm40608_ReadGyro(&picm40608data->gyro_data);
}

void Icm40608_Gyro_Value_Get(float *gyr_real_x, float *gyr_real_y, float *gyr_real_z)
{
    float gyr_resolution = 0.0;

    uint8_t data;
    GyroData_St gyrodata = {0};

    icm40608_register_read(GYRO_CONFIG0, &data, 1);
    uint32_t range = (data & (0x07 << 5));
    switch (range)
    {
    case ICM40608_GYRO_RANGE_2000:
        gyr_resolution = 16.4; //2000
        break;
    case ICM40608_GYRO_RANGE_1000:
        gyr_resolution = 32.8; //1000
        break;
    case ICM40608_GYRO_RANGE_500:
        gyr_resolution = 65.6f; //500
        break;
    case ICM40608_GYRO_RANGE_250:
        gyr_resolution = 131.0f; //250
        break;
    case ICM40608_GYRO_RANGE_125:
        gyr_resolution = 262.0f; //125
        break;
    default:
        gyr_resolution = 16.4; //2000
        break;
    }

    Icm40608_ReadGyro(&gyrodata);
    if (gyrodata.gyro_x != 0)
        *gyr_real_x = (int16_t)gyrodata.gyro_x / gyr_resolution; //°/S
    else
        *gyr_real_x = 0.0;

    if (gyrodata.gyro_y != 0)
        *gyr_real_y = (int16_t)gyrodata.gyro_y / gyr_resolution; //°/S
    else
        *gyr_real_y = 0.0;

    if (gyrodata.gyro_z != 0)
        *gyr_real_z = (int16_t)gyrodata.gyro_z / gyr_resolution; //°/S
    else
        *gyr_real_z = 0.0;
}


void Icm40608_ACC_Value_Get(float *acc_real_x, float *acc_real_y, float *acc_real_z)
{
    float acc_resolution = 0.0;
    uint8_t data = 0;

    icm40608_register_read(ACCEL_CONFIG0, &data, 1);
    uint32_t range = (data & (0x07 << 5));

    switch (range)
    {
    case ICM40608_ACC_RANGE_2G:
        acc_resolution = 16384; //2g
        break;
    case ICM40608_ACC_RANGE_4G:
        acc_resolution = 8192; //4g
        break;
    case ICM40608_ACC_RANGE_8G:
        acc_resolution = 4096; //8g
        break;
    case ICM40608_ACC_RANGE_16G:
        acc_resolution = 2048; //16g
        break;
    default:
        acc_resolution = 16384; //2g
        break;
    }
    AccData_St accdata = {0};
    Icm40608_ReadAcc(&accdata);
    if (accdata.acc_x != 0)
        *acc_real_x = (int16_t)accdata.acc_x * 1.0 / acc_resolution; //g
    else
        *acc_real_x = 0.0;

    if (accdata.acc_y != 0)
        *acc_real_y = (int16_t)accdata.acc_y * 1.0 / acc_resolution; //g
    else
        *acc_real_y = 0.0;

    if (accdata.acc_z != 0)
        *acc_real_z = (int16_t)accdata.acc_z * 1.0 / acc_resolution; //g
    else
        *acc_real_z = 0.0;
}

#define ACC_X_Y_MIN_VALUE (0.0f)
#define ACC_X_Y_MAX_VALUE (0.2f)
#define ACC_Z_MIN_VALUE (0.0f)
#define ACC_Z_MAX_VALUE (1.2f)

#define GYRO_X_Y_MIN_VALUE  (0)
#define GYRO_X_Y_MAX_VALUE  (0)

bool icm40608_test(void)
{
    

    if (DEVICE_ID != Icm40608_read_ID())
    {
        return false;
    }
    return true;
    #if 0
	float accx,accy,accz,gyrox,gyroy,gyroz;
    Icm40608_ACC_Value_Get(&accx,&accy,&accz);

    if((accx + accy) < 2*ACC_X_Y_MIN_VALUE || (accx + accy) > 2*ACC_X_Y_MAX_VALUE)
    {
        return false;
    }

    if(accz < ACC_Z_MIN_VALUE || accz > ACC_Z_MAX_VALUE)
    {
        return false;
    }
    Icm40608_Gyro_Value_Get(&gyrox,&gyroy,&gyroz);
    #endif

}
//获取加速度传感器的值，目前还没有用到，先注释
#if 0
static void ACC_Value2Rawdata(float real_x, float real_y, float real_z, int16_t *x, int16_t *y, int16_t *z)
{
    uint16_t resolution = 0;
    double tmp_x = 0, tmp_y = 0, tmp_z = 0;

    uint8_t data = 0;

    icm40608_register_read(GYRO_CONFIG0, &data, 1);
    uint32_t range = (data & (0x07 << 5));
    switch (range)
    {
    case ICM40608_ACC_RANGE_2G:
        resolution = 16384; //2g
        break;
    case ICM40608_ACC_RANGE_4G:
        resolution = 8192; //4g
        break;
    case ICM40608_ACC_RANGE_8G:
        resolution = 4096; //8g
        break;
    case ICM40608_ACC_RANGE_16G:
        resolution = 2048; //16g
        break;
    default:
        resolution = 16384; //2g
        break;
    }
    tmp_x = real_x * resolution;
    *x = (int16_t)tmp_x;
    tmp_y = real_y * resolution;
    *y = (int16_t)tmp_y;
    tmp_z = real_z * resolution;
    *z = (int16_t)tmp_z;
}
#endif

void Icm40608_Acc_GetRawData(uint8_t *data)
{
    if (!data)
    {
        return;
    }
#if 0
    uint8_t buf[6];

    icm40608_register_read(ACCEL_DATA_X1, buf, 6);

    memcpy(data, buf, sizeof(buf));
#else
    AccData_St accdata;
    data_union x, y, z;
    Icm40608_ReadAcc(&accdata);

    x.data = accdata.acc_x;
    y.data = accdata.acc_y;
    z.data = accdata.acc_z;

    data[0] = x.data_uint[1];
    data[1] = x.data_uint[0];
    data[2] = y.data_uint[1];
    data[3] = y.data_uint[0];
    data[4] = z.data_uint[1];
    data[5] = z.data_uint[0];
#endif
}

void Icm40608_Gyro_GetRawData(uint8_t *data)
{
    data_union x, y, z;
    if (!data)
    {
        return;
    }
#if 0
    float real_x = 0, real_y = 0, real_z = 0;
    Icm40608_Gyro_Value_Get(&real_x, &real_y, &real_z);
    GYR_Value2Rawdata(real_x, real_y, real_z, &x.data, &y.data, &z.data);
#else
    GyroData_St gyrodata;
    Icm40608_ReadGyro(&gyrodata);

    x.data = gyrodata.gyro_x;
    y.data = gyrodata.gyro_y;
    z.data = gyrodata.gyro_z;
#endif
    data[0] = x.data_uint[1];
    data[1] = x.data_uint[0];
    data[2] = y.data_uint[1];
    data[3] = y.data_uint[0];
    data[4] = z.data_uint[1];
    data[5] = z.data_uint[0];
}

/*
 * Icm406xx driver needs to get time in us. Let's give its implementation here.
 */
uint64_t inv_icm406xx_get_time_us(void)
{
	if(inviicopera.inv_systick_get)
	{
		return inviicopera.inv_systick_get();
	}
    return 0;
}
/*
 * Icm406xx driver needs a sleep feature from external device. Thus inv_icm406xx_sleep_us
 * is defined as extern symbol in driver. Let's give its implementation here.
 */
void inv_icm406xx_sleep_us(uint32_t us)
{
	if(inviicopera.inv_systick_sleep)
	{
		inviicopera.inv_systick_sleep(us);
	}
}

static void sensor_event_cb(inv_icm406xx_sensor_event_t * event)
{
	if(inviicopera.get_rawdata)
	{
		inviicopera.get_rawdata(event->accel,event->gyro);
	}
}

int icm40608_getdata_fifo(void)
{
	
	return inv_icm406xx_get_data_from_fifo(&icm_driver);
}


/* --------------------------------------------------------------------------------------
 *  Functions definition
 * -------------------------------------------------------------------------------------- */
int SetupInvDevice(struct inv_icm406xx_serif *icm_serif)
{
    int rc = 0;
    uint8_t who_am_i;

//    NRF_LOG_INFO("#########################");
//    NRF_LOG_INFO("#   Pedometer example   #");
//    NRF_LOG_INFO("#########################");

    /* Init device */
//    NRF_LOG_INFO("Initialize Icm406xx");

    rc = inv_icm406xx_init(&icm_driver, icm_serif, sensor_event_cb);
    if (rc != INV_ERROR_SUCCESS)
    {
//        NRF_LOG_INFO("!!! ERROR : failed to initialize Icm406xx.");
        return rc;
    }

    /* Check WHOAMI */
//    NRF_LOG_INFO("Check Icm406xx whoami value");

    rc = inv_icm406xx_get_who_am_i(&icm_driver, &who_am_i);
    if (rc != INV_ERROR_SUCCESS)
    {
//        NRF_LOG_INFO("!!! ERROR : failed to read Icm406xx whoami value.");
        return rc;
    }

    if (who_am_i != ICM_WHOAMI)
    {
//        NRF_LOG_INFO("!!! ERROR :  bad WHOAMI value. Got 0x%02x (expected: 0x%02x)", who_am_i, ICM_WHOAMI);
        return INV_ERROR;
    }

//    NRF_LOG_INFO("Check ok");
    return rc;
}

int ConfigureInvDevice(ICM406XX_APEX_CONFIG0_DMP_ODR_t pedometer_freq,
                       ICM406XX_APEX_CONFIG0_DMP_POWER_SAVE_t power_mode,
                       ICM406XX_APEX_CONFIG2_PEDO_AMP_TH_t pedo_amp_th,
                       uint8_t pedo_step_cnt_th,
                       ICM406XX_APEX_CONFIG3_PEDO_SB_TIMER_TH_t pedo_sb_timer_th,
                       uint8_t pedo_step_det_th,
                       ICM406XX_APEX_CONFIG9_SENSITIVITY_MODE_t sensitivity_mode)
{
    int rc = 0;
    ICM406XX_ACCEL_CONFIG0_ODR_t acc_freq;
    inv_icm406xx_apex_parameters_t apex_inputs;
    inv_icm406xx_interrupt_parameter_t config_int = {(inv_icm406xx_interrupt_value)0};

    /* Accel frequency should be at least or higher than the Pedometer frequency to properly running the APEX feature */
    switch (pedometer_freq)
    {
    case ICM406XX_APEX_CONFIG0_DMP_ODR_25Hz:
        acc_freq = ICM406XX_ACCEL_CONFIG0_ODR_25_HZ;
//        dmp_odr_hz = 25;
        break;

    case ICM406XX_APEX_CONFIG0_DMP_ODR_50Hz:
        acc_freq = ICM406XX_ACCEL_CONFIG0_ODR_50_HZ;
//        dmp_odr_hz = 50;
        break;

    default:
        return INV_ERROR_BAD_ARG;
    }

	acc_freq = ICM406XX_ACCEL_CONFIG0_ODR_200_HZ;
//	dmp_odr_hz = 25;
    /* Enable accelerometer to feed the APEX Pedometer algorithm */
    rc |= inv_icm406xx_set_accel_frequency(&icm_driver, acc_freq);

    /* Set 1x averaging, in order to minimize power consumption (16x by default) */
    rc |= inv_icm406xx_set_accel_lp_avg(&icm_driver, ICM406XX_GYRO_ACCEL_CONFIG0_ACCEL_FILT_AVG_1);

    rc |= inv_icm406xx_enable_accel_low_power_mode(&icm_driver);

    /* Get the default parameters for the APEX features */
    rc |= inv_icm406xx_init_apex_parameters_struct(&icm_driver, &apex_inputs);

    /* Configure the programmable parameters */
    apex_inputs.pedo_amp_th = pedo_amp_th;
    apex_inputs.pedo_step_cnt_th = pedo_step_cnt_th;
    apex_inputs.pedo_sb_timer_th = pedo_sb_timer_th;
    apex_inputs.pedo_step_det_th = pedo_step_det_th;
    apex_inputs.sensitivity_mode = sensitivity_mode;

    /* Configure the programmable parameter for Low Power mode (WoM+Pedometer) or Normal mode */
    if (power_mode == ICM406XX_APEX_CONFIG0_DMP_POWER_SAVE_EN)
    {
        /* Enable WOM to wake-up the DMP once it goes in power save mode */
        rc |= inv_icm406xx_enable_wom(&icm_driver); /* Enable WOM and disable fifo threshold */

        apex_inputs.power_save = ICM406XX_APEX_CONFIG0_DMP_POWER_SAVE_EN;
    }
    else
        apex_inputs.power_save = ICM406XX_APEX_CONFIG0_DMP_POWER_SAVE_DIS;

    /* Initializes APEX features */
    rc |= inv_icm406xx_configure_apex_parameters(&icm_driver, &apex_inputs);
    rc |= inv_icm406xx_set_apex_frequency(&icm_driver, pedometer_freq);

    /* Enable the pedometer */
    rc |= inv_icm406xx_enable_apex_pedometer(&icm_driver);

    /* Disable fifo threshold, data ready and WOM interrupts INT1 */
    inv_icm406xx_get_config_int1(&icm_driver, &config_int);
    config_int.INV_ICM406XX_FIFO_THS = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_UI_DRDY = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_WOM_X = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_WOM_Y = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_WOM_Z = INV_ICM406XX_DISABLE;
	
	//²»Ê¹ÄÜÖÐ¶Ï¹¦ÄÜ
	config_int.INV_ICM406XX_STEP_CNT_OVFL = INV_ICM406XX_DISABLE;
	config_int.INV_ICM406XX_STEP_DET = INV_ICM406XX_DISABLE;
	
    inv_icm406xx_set_config_int1(&icm_driver, &config_int);

    /* Disable fifo threshold, data ready and WOM interrupts IBI */
    inv_icm406xx_get_config_ibi(&icm_driver, &config_int);
    config_int.INV_ICM406XX_FIFO_THS = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_UI_DRDY = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_WOM_X = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_WOM_Y = INV_ICM406XX_DISABLE;
    config_int.INV_ICM406XX_WOM_Z = INV_ICM406XX_DISABLE;
	
	//²»Ê¹ÄÜÖÐ¶Ï¹¦ÄÜ
	config_int.INV_ICM406XX_STEP_CNT_OVFL = INV_ICM406XX_DISABLE;
	config_int.INV_ICM406XX_STEP_DET = INV_ICM406XX_DISABLE;
	
    inv_icm406xx_set_config_ibi(&icm_driver, &config_int);

    return rc;
}

int ConfigureInvDevice_fifo(ICM406XX_ACCEL_CONFIG0_FS_SEL_t acc_fsr_g,
                       ICM406XX_GYRO_CONFIG0_FS_SEL_t gyr_fsr_dps,
                       ICM406XX_ACCEL_CONFIG0_ODR_t acc_freq,
                       ICM406XX_GYRO_CONFIG0_ODR_t gyr_freq)
{
	int rc = 0;
	rc |= inv_icm406xx_set_accel_fsr(&icm_driver, acc_fsr_g);
	rc |= inv_icm406xx_set_gyro_fsr(&icm_driver, gyr_fsr_dps);
	
	rc |= inv_icm406xx_set_accel_frequency(&icm_driver, acc_freq);
	rc |= inv_icm406xx_set_gyro_frequency(&icm_driver, gyr_freq);
	
	rc |= inv_icm406xx_enable_accel_low_power_mode(&icm_driver);
	
	rc |= inv_icm406xx_enable_gyro_low_noise_mode(&icm_driver);

	return rc;
}

void icm40608_open(void)
{
//	inv_icm406xx_enable_accel_low_power_mode(&icm_driver);
//	
//	inv_icm406xx_set_accel_frequency(&icm_driver,ICM406XX_ACCEL_CONFIG0_ODR_200_HZ);
	
	ConfigureInvDevice(ICM_PEDOMETER_FREQUENCY_MODE,
                            ICM_PEDOMETER_POWER_SAVE_MODE,
                            ICM_PEDOMETER_VALID_STEP_THRESHOLD,
                            ICM_PEDOMETER_STEP_COUNTER_THRESHOLD,
                            ICM_PEDOMETER_NON_WALK_DURATION,
                            ICM_PEDOMETER_STEP_DETECTOR_THRESHOLD,
                            ICM_PEDOMETER_SENSITIVITY_MODE);
	
//	inv_icm406xx_set_accel_fsr(&icm_driver,ICM406XX_ACCEL_CONFIG0_FS_SEL_4g);
	
	inv_icm406xx_enable_gyro_low_noise_mode(&icm_driver);
	
	inv_icm406xx_set_gyro_frequency(&icm_driver,ICM406XX_GYRO_CONFIG0_ODR_100_HZ);
	
//	inv_icm406xx_set_gyro_fsr(&icm_driver,ICM406XX_GYRO_CONFIG0_FS_SEL_2000dps);
	
}

int icm40608_fifo_config(ACC_RANGE_E accrange,GYRO_RANGE_E gyrorange,ACC_CONFIG0_ODR_t accodr,GYRO_CONFIG0_ODR_t gyroodr)
{
	SetupInvDevice(&icm406xx_serif);
	
	return ConfigureInvDevice_fifo((ICM406XX_ACCEL_CONFIG0_FS_SEL_t)accrange,(ICM406XX_GYRO_CONFIG0_FS_SEL_t)gyrorange,(ICM406XX_ACCEL_CONFIG0_ODR_t)accodr,(ICM406XX_GYRO_CONFIG0_ODR_t)gyroodr);
}

void icm40608_close(void)
{
	int status = inv_icm406xx_disable_accel(&icm_driver);
//	NRF_LOG_INFO("status:%d\n",status);
	
	status = inv_icm406xx_disable_gyro(&icm_driver);
//	NRF_LOG_INFO("status:%d\n",status);
	
	if(inviicopera.close_cb)
	{
		inviicopera.close_cb();
	}
}

/* I2C slave address for INV device */
#define ICM_I2C_ADDR 0x68

static int inv_io_hal_read_reg(struct inv_icm406xx_serif * serif, uint8_t reg, uint8_t *rbuffer, uint32_t rlen)
{
    if(rlen >= 256)
    {
        return -1;
    }

    inviicopera.write_fun(ICM_I2C_ADDR,&reg,1,true);
    inviicopera.read_fun(ICM_I2C_ADDR, rbuffer, rlen);
    return 0;
}
static int inv_io_hal_write_reg(struct inv_icm406xx_serif * serif, uint8_t reg, const uint8_t *wbuffer, uint32_t wlen)
{
    uint8_t w2_data[256];
    if(wlen >= 256)
    {
        return -1;
    }
    w2_data[0] = reg;
    memcpy(&w2_data[1], wbuffer, wlen);
    inviicopera.write_fun(ICM_I2C_ADDR, w2_data, wlen+1, false);
    return 0;
}


void icm40608_config(void)
{

    /* Initialize serial inteface between MCU and Icm406xx */
    icm406xx_serif.context = 0; /* no need */
    icm406xx_serif.read_reg = inv_io_hal_read_reg;
    icm406xx_serif.write_reg = inv_io_hal_write_reg;
    icm406xx_serif.max_read = 256;
    icm406xx_serif.max_write = 256;
    icm406xx_serif.serif_type = ICM406XX_UI_I2C;
	SetupInvDevice(&icm406xx_serif);
	
	icm40608_close();
}

void icm40608_init(iic_write write_fun,iic_read read_fun,systick_get systick_get_fun,sys_sleep_us sys_sleep_us_fun,int_get_rawdata get_rawdata_fun)
{
	inviicopera.read_fun = read_fun;
    inviicopera.write_fun = write_fun;
	inviicopera.inv_systick_get = systick_get_fun;
	inviicopera.inv_systick_sleep = sys_sleep_us_fun;
	inviicopera.get_rawdata = get_rawdata_fun;
	
    icm40608_config();
}

void icm40608_close_cb_register(icm40608_close_cb close_cb)
{
	inviicopera.close_cb = close_cb;
}
int Icm40608_Acc_Odr_Set(ACC_CONFIG0_ODR_t odr)
{
	return inv_icm406xx_set_accel_frequency(&icm_driver,(ICM406XX_ACCEL_CONFIG0_ODR_t)odr);
}

int Icm40608_Gyro_Odr_Set(ACC_CONFIG0_ODR_t odr)
{
	return inv_icm406xx_set_gyro_frequency(&icm_driver, (ICM406XX_GYRO_CONFIG0_ODR_t)odr);
}
