
/********************
*    register map
*********************/
#ifndef		__ICM40608_H
#define		__ICM40608_H
#include <stdint.h>
#include <stdbool.h>
typedef enum
{
    ICM40608_ACC_RANGE_2G  = 0x03 << 5,
    ICM40608_ACC_RANGE_4G  = 0x02 << 5,
    ICM40608_ACC_RANGE_8G  = 0x01 << 5,
    ICM40608_ACC_RANGE_16G = 0x00 << 5
}ACC_RANGE_E;

typedef enum
{
	ICM40608_GYRO_RANGE_16  = 0x07 << 5,
    ICM40608_GYRO_RANGE_31  = 0x06 << 5,
    ICM40608_GYRO_RANGE_64  = 0x05 << 5,
    ICM40608_GYRO_RANGE_125  = 0x04 << 5,
    ICM40608_GYRO_RANGE_250  = 0x03 << 5,
    ICM40608_GYRO_RANGE_500  = 0x02 << 5,
    ICM40608_GYRO_RANGE_1000 = 0x01 << 5,
    ICM40608_GYRO_RANGE_2000 = 0x00 << 5,
}GYRO_RANGE_E;


typedef enum
{
    ICM40608_GYRO_OFF,       
    ICM40608_GYRO_STANDBY, 
    ICM40608_GYRO_LN,        
    ICM40608_ACCEL_OFF,     
    ICM40608_ACCEL_LN ,      
    ICM40608_ACCEL_LP ,      
}ICM40608_WORKMODE_SET_E;

typedef enum
{
	GYRO_CONFIG0_ODR_500_HZ    = 0x0F,  /*!< 500 Hz (2 ms)*/
	GYRO_CONFIG0_ODR_12_5_HZ   = 0x0B,  /*!< 12.5 Hz (80 ms)*/
	GYRO_CONFIG0_ODR_25_HZ     = 0x0A,  /*!< 25 Hz (40 ms)*/
	GYRO_CONFIG0_ODR_50_HZ     = 0x09,  /*!< 50 Hz (20 ms)*/
	GYRO_CONFIG0_ODR_100_HZ    = 0x08,  /*!< 100 Hz (10 ms)*/
	GYRO_CONFIG0_ODR_200_HZ    = 0x07,  /*!< 200 Hz (5 ms)*/
	GYRO_CONFIG0_ODR_1_KHZ     = 0x06,  /*!< 1 KHz (1 ms)*/
}GYRO_CONFIG0_ODR_t;

typedef enum
{
	ACCEL_CONFIG0_ODR_500_HZ    = 0xF,  /*!< 500 Hz (2 ms)*/
	ACCEL_CONFIG0_ODR_1_5625_HZ = 0xE,  /*!< 1.5625 Hz (640 ms)*/
	ACCEL_CONFIG0_ODR_3_125_HZ  = 0xD,  /*!< 3.125 Hz (320 ms)*/
	ACCEL_CONFIG0_ODR_6_25_HZ   = 0xC,  /*!< 6.25 Hz (160 ms)*/
	ACCEL_CONFIG0_ODR_12_5_HZ   = 0xB,  /*!< 12.5 Hz (80 ms)*/
	ACCEL_CONFIG0_ODR_25_HZ     = 0xA,  /*!< 25 Hz (40 ms)*/
	ACCEL_CONFIG0_ODR_50_HZ     = 0x9,  /*!< 50 Hz (20 ms)*/
	ACCEL_CONFIG0_ODR_100_HZ    = 0x8,  /*!< 100 Hz (10 ms)*/
	ACCEL_CONFIG0_ODR_200_HZ    = 0x7,  /*!< 200 Hz (5 ms)*/
	ACCEL_CONFIG0_ODR_1_KHZ     = 0x6,  /*!< 1 KHz (1 ms)*/
}ACC_CONFIG0_ODR_t;


typedef struct
{
    short acc_x;
    short acc_y;
    short acc_z;
}AccData_St;

typedef AccData_St* PAccData_St;
typedef struct
{
   
    short gyro_x;
    short gyro_y;
    short gyro_z;    
}GyroData_St;

typedef GyroData_St*  PGyroData_St;

typedef struct
{
    AccData_St  acc_data;
    GyroData_St gyro_data;
}Icm40608Data_St;
typedef Icm40608Data_St* PIcm40608Data_St;


void Icm40608_Read_AllData(PIcm40608Data_St pmpu6050data);

void Icm40608_ReadGyro(PGyroData_St pgyrodata);

void Icm40608_ReadAcc(PAccData_St paccdata);

void Icm40608_Mode_Set(ICM40608_WORKMODE_SET_E workmode);

void Icm40608_Gyro_Value_Get(float *gyr_real_x, float *gyr_real_y, float *gyr_real_z);

void Icm40608_ACC_Value_Get(float *acc_real_x, float *acc_real_y, float *acc_real_z);


typedef void (*iic_write)(uint8_t writeaddress, uint8_t *pdata, uint8_t length, bool no_stop);
typedef void (*iic_read)(uint8_t readaddress, uint8_t *pdata, uint8_t length);
typedef void (*int_get_rawdata)(int16_t *,int16_t*);
typedef void (*icm40608_close_cb)(void);

typedef uint32_t (*systick_get)(void);
typedef void (*sys_sleep_us)(uint32_t);

void Icm40608_Acc_GetRawData(uint8_t* data);
void Icm40608_Gyro_GetRawData(uint8_t* data);

uint16_t Icm40608_Gyro_Range_Get(void);
void Icm40608_Gyro_Range_Set(GYRO_RANGE_E range);

void Icm40608_Acc_Range_Set(ACC_RANGE_E range);
uint8_t Icm40608_Acc_Range_Get(void);

int Icm40608_Acc_Odr_Set(ACC_CONFIG0_ODR_t);
int Icm40608_Gyro_Odr_Set(ACC_CONFIG0_ODR_t);

void Icm40608_Gyro_Poweroff(void);

int icm40608_getdata_fifo(void);

int icm40608_fifo_config(ACC_RANGE_E,GYRO_RANGE_E,ACC_CONFIG0_ODR_t,GYRO_CONFIG0_ODR_t);

void icm40608_init(iic_write ,iic_read ,systick_get ,sys_sleep_us ,int_get_rawdata);

void icm40608_close_cb_register(icm40608_close_cb);

void icm40608_close(void);
void icm40608_open(void);

bool icm40608_test(void);

#endif		//__ICM40608_H
